/*****************************************************************************
 * Copyright (C) The Apache Software Foundation. All rights reserved.        *
 * ------------------------------------------------------------------------- *
 * This software is published under the terms of the Apache Software License *
 * version 1.1, a copy of which has been included with this distribution in  *
 * the LICENSE file.                                                         *
 *****************************************************************************/

package org.apache.batik.gvt;

import java.awt.Shape;
import java.awt.Graphics2D;

/**
 * Renders the shape of a <tt>ShapeNode</tt>.
 *
 * @author <a href="mailto:Thierry.Kormann@sophia.inria.fr">Thierry Kormann</a>
 * @version $Id: ShapePainter.java,v 1.5 2001/02/06 01:56:39 vhardy Exp $
 */
public interface ShapePainter {

    /**
     * Paints the specified shape using the specified Graphics2D and context.
     * @param g2d the Graphics2D to use
     * @param ctx the render context to use
     */
    void paint(Graphics2D g2d, GraphicsNodeRenderContext ctx);

    /**
     * Returns the area painted by this painter
     *
     */
    Shape getPaintedArea(GraphicsNodeRenderContext rc);

    /**
     * Sets the Shape this painter is associated with.
     * @param shape new shape this painter should be associated with.
     *        should not be null.
     */
    public void setShape(Shape shape);

    /**
     * Gets the Shape this painter is associated with.
     *
     * @return shape associated with this Painter.
     */
    public Shape getShape();
}
